Обновлены маски

atratsevskiy
Alexander Tratsevskiy 8 years ago
parent 1e993b5022
commit de2e8698c9

@ -1 +0,0 @@
DIST cinnamon-3.0.7.tar.gz 3065791 SHA256 0aa0ce174a4638f54ddb2f0dc1f93a847678fa225c7a4fae718ffd14f1c8694f SHA512 db3f2532525c71b0841ce22245518502f8e905fd353c22e41dc57551cf68422ab6b53a57e4089664e8db9035a7723214756de78d2b5d5a92e11515216b15afbf WHIRLPOOL 7f7e0f3841d8790f332342e9d0696c8f70e81657ea02e1374871505be1c5ecdb7e9d4fc4fd0d600bf69fcd856123a58d5b272b4de03f9dd7d4c7d3d8278154b0

@ -1,239 +0,0 @@
# Copyright 1999-2016 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Id$
EAPI=6
GNOME2_LA_PUNT="yes"
PYTHON_COMPAT=( python{2_7,3_3,3_4,3_5} )
PYTHON_REQ_USE="xml"
inherit autotools eutils flag-o-matic gnome2 multilib pax-utils python-r1
DESCRIPTION="A fork of GNOME Shell with layout similar to GNOME 2"
HOMEPAGE="http://cinnamon.linuxmint.com/"
MY_PV="${PV/_p/-UP}"
MY_P="${PN}-${MY_PV}"
SRC_URI="https://github.com/linuxmint/Cinnamon/archive/${MY_PV}.tar.gz -> ${MY_P}.tar.gz"
LICENSE="GPL-2+"
SLOT="0"
# bluetooth support dropped due to bug #511648
IUSE="+nls +networkmanager" #+bluetooth
# We need *both* python 2.7 and 3.x
REQUIRED_USE="${PYTHON_REQUIRED_USE}
python_targets_python2_7
|| ( python_targets_python3_4 python_targets_python3_5 )
"
KEYWORDS="~amd64 ~x86"
COMMON_DEPEND="${PYTHON_DEPS}
app-accessibility/at-spi2-atk:2
app-misc/ca-certificates
dev-libs/dbus-glib
>=dev-libs/glib-2.35.0:2[dbus]
>=dev-libs/gobject-introspection-0.10.1:=
>=dev-libs/json-glib-0.13.2
>=dev-libs/libcroco-0.6.2:0.6
dev-libs/libxml2:2
gnome-base/gconf:2[introspection]
gnome-base/librsvg
>=gnome-extra/cinnamon-desktop-2.4:0=[introspection]
gnome-extra/cinnamon-menus[introspection]
>=gnome-extra/cjs-2.8.0
>=media-libs/clutter-1.10:1.0[introspection]
media-libs/cogl:1.0=[introspection]
>=gnome-base/gsettings-desktop-schemas-2.91.91
media-libs/gstreamer:1.0
media-libs/gst-plugins-base:1.0
net-libs/libsoup:2.4[introspection]
>=sys-auth/polkit-0.100[introspection]
x11-libs/gdk-pixbuf:2[introspection]
>=x11-libs/gtk+-3.9.12:3[introspection]
x11-libs/pango[introspection]
>=x11-libs/startup-notification-0.11
x11-libs/libX11
>=x11-libs/libXfixes-5.0
>=x11-wm/muffin-3.0.0[introspection]
networkmanager? (
gnome-base/libgnome-keyring
>=net-misc/networkmanager-0.8.999:=[introspection] )
"
#bluetooth? ( >=net-wireless/gnome-bluetooth-3.1:=[introspection] )
# Runtime-only deps are probably incomplete and approximate.
# Each block:
# 2. Introspection stuff + dconf needed via imports.gi.*
# 3. gnome-session is needed for gnome-session-quit
# 4. Control shell settings
# 5. accountsservice is needed for GdmUserManager (0.6.14 needed for fast
# user switching with gdm-3.1.x)
# 6. caribou needed for on-screen keyboard
# 7. xdg-utils needed for xdg-open, used by extension tool
# 8. gconf-python, imaging, lxml needed for cinnamon-settings
# 9. gnome-icon-theme-symbolic needed for various icons
# 10. pygobject needed for menu editor
# 11. nemo - default file manager, tightly integrated with cinnamon
# 12. polkit-gnome - explicitly autostarted by us
# TODO(lxnay): fix error: libgnome-desktop/gnome-rr-labeler.h: No such file or directory
RDEPEND="${COMMON_DEPEND}
>=gnome-base/dconf-0.4.1
>=gnome-base/libgnomekbd-2.91.4[introspection]
|| ( sys-power/upower[introspection] sys-power/upower-pm-utils[introspection] )
>=gnome-extra/cinnamon-session-2.4
>=gnome-extra/cinnamon-settings-daemon-2.4
>=sys-apps/accountsservice-0.6.14[introspection]
>=app-accessibility/caribou-0.3
x11-misc/xdg-utils
dev-python/dbus-python[python_targets_python2_7]
dev-python/gconf-python:2[python_targets_python2_7]
dev-python/lxml[python_targets_python2_7]
dev-python/pexpect[python_targets_python2_7]
dev-python/pycairo[python_targets_python2_7]
dev-python/pygobject:3[${PYTHON_USEDEP}]
dev-python/pyinotify[python_targets_python2_7]
dev-python/pypam[python_targets_python2_7]
dev-python/pillow[python_targets_python2_7]
x11-themes/gnome-themes-standard
x11-themes/adwaita-icon-theme
>=gnome-extra/nemo-2.4
>=gnome-extra/cinnamon-control-center-2.4
>=gnome-extra/cinnamon-screensaver-2.4
gnome-extra/polkit-gnome
networkmanager? (
gnome-extra/nm-applet
net-misc/mobile-broadband-provider-info
sys-libs/timezone-data )
nls? ( >=gnome-extra/cinnamon-translations-2.4 )
"
#bluetooth? ( net-wireless/cinnamon-bluetooth )
DEPEND="${COMMON_DEPEND}
dev-python/polib[python_targets_python2_7]
dev-util/gtk-doc
>=dev-util/intltool-0.4
>=sys-devel/gettext-0.17
virtual/pkgconfig
gnome-base/gnome-common
!!=dev-lang/spidermonkey-1.8.2*
"
# libmozjs.so is picked up from /usr/lib while compiling, so block at build-time
# https://bugs.gentoo.org/show_bug.cgi?id=360413
S="${WORKDIR}/Cinnamon-${PV}"
pkg_setup() {
python_setup
}
src_prepare() {
# Fix backgrounds path as cinnamon doesn't provide them
# https://github.com/linuxmint/Cinnamon/issues/3575
eapply "${FILESDIR}"/${PN}-2.8.0-background.patch
# Fix automagic gnome-bluetooth dep, bug #398145
eapply "${FILESDIR}"/${PN}-2.2.6-automagic-gnome-bluetooth.patch
# Optional NetworkManager, bug #488684
eapply "${FILESDIR}"/${PN}-2.6.7-optional-networkmanager.patch
# Use wheel group instead of sudo (from Fedora/Arch)
# https://github.com/linuxmint/Cinnamon/issues/3576
eapply "${FILESDIR}"/${PN}-2.8.3-set-wheel.patch
# Use pkexec instead of gksu (from Arch)
# https://github.com/linuxmint/Cinnamon/issues/3565
sed -i 's/gksu/pkexec/' files/usr/bin/cinnamon-settings-users || die
# Add polkit agent to required components (from Fedora/Arch), bug #523958
# https://github.com/linuxmint/Cinnamon/issues/3579
sed -i 's/RequiredComponents=\(.*\)$/RequiredComponents=\1polkit-gnome-authentication-agent-1;/' \
files/usr/share/cinnamon-session/sessions/cinnamon*.session || die
if ! use networkmanager; then
rm -rv files/usr/share/cinnamon/applets/network@cinnamon.org || die
fi
# python 2-and-3 shebang fixing craziness
local p
python_setup 'python3*'
for p in $(grep -rl '#!.*python3'); do
python_fix_shebang "${p}"
done
python_setup 'python2*'
for p in $(grep -rl '#!.*python[^3]'); do
python_fix_shebang "${p}"
done
eautoreconf
gnome2_src_prepare
}
src_configure() {
# https://bugs.gentoo.org/show_bug.cgi?id=536374
# https://github.com/linuxmint/Cinnamon/issues/3843
append-ldflags $(no-as-needed)
gnome2_src_configure \
--libdir="${EPREFIX}/usr/$(get_libdir)" \
--disable-rpath \
--disable-jhbuild-wrapper-script \
$(use_enable networkmanager) \
--with-ca-certificates="${EPREFIX}/etc/ssl/certs/ca-certificates.crt" \
BROWSER_PLUGIN_DIR="${EPREFIX}/usr/$(get_libdir)/nsbrowser/plugins" \
--without-bluetooth
}
src_install() {
gnome2_src_install
python_optimize "${ED}"usr/$(get_libdir)/cinnamon-*
# Required for gnome-shell on hardened/PaX, bug #398941
pax-mark mr "${ED}usr/bin/cinnamon"
# Doesn't exist on Gentoo, causing this to be a dead symlink
rm -f "${ED}etc/xdg/menus/cinnamon-applications-merged" || die
# Ensure authentication-agent is started, bug #523958
# https://github.com/linuxmint/Cinnamon/issues/3579
insinto /etc/xdg/autostart/
doins "${FILESDIR}"/polkit-cinnamon-authentication-agent-1.desktop
}
pkg_postinst() {
gnome2_pkg_postinst
if ! has_version 'media-libs/gst-plugins-good:1.0' || \
! has_version 'media-plugins/gst-plugins-vpx:1.0'; then
ewarn "To make use of Cinnamon's built-in screen recording utility,"
ewarn "you need to either install media-libs/gst-plugins-good:1.0"
ewarn "and media-plugins/gst-plugins-vpx:1.0, or use dconf-editor to change"
ewarn "org.cinnamon.recorder/pipeline to what you want to use."
fi
if ! has_version ">=x11-base/xorg-server-1.11"; then
ewarn "If you use multiple screens, it is highly recommended that you"
ewarn "upgrade to >=x11-base/xorg-server-1.11 to be able to make use of"
ewarn "pointer barriers which will make it easier to use hot corners."
fi
if has_version "<x11-drivers/ati-drivers-12"; then
ewarn "Cinnamon has been reported to show graphical corruption under"
ewarn "x11-drivers/ati-drivers-11.*; you may want to switch to"
ewarn "open-source drivers."
fi
}

@ -1,44 +0,0 @@
From 40750fc87b7a1cad60d0e605732b9df50dd16c11 Mon Sep 17 00:00:00 2001
From: root <admin@catmur.co.uk>
Date: Sun, 8 Jan 2012 13:55:05 +0000
Subject: [PATCH] Fix automagic gnome-bluetooth dependency
https://bugs.gentoo.org/show_bug.cgi?id=398145
Ed Catmur 2012-01-08 13:46:22 UTC
libgnome-bluetooth-applet is a private library so they shouldn't be linking
against it anyway. I tried to work out how to tell libtool to add it to rpath
but got totally lost.
I'll see if I can work out how to fix the automagic gnome-bluetooth dependency
so I can at least merge USE=-bluetooth.
---
configure.ac | 5 +++++
1 file changed, 5 insertions(+)
diff --git a/configure.ac b/configure.ac
index c0e43e1..bc764e1 100644
--- a/configure.ac
+++ b/configure.ac
@@ -111,6 +111,8 @@ PKG_CHECK_MODULES(GVC, libpulse libpulse-mainloop-glib gobject-2.0)
PKG_CHECK_MODULES(DESKTOP_SCHEMAS, cinnamon-desktop >= 1.0.0)
AC_MSG_CHECKING([for bluetooth support])
+AC_ARG_WITH([bluetooth], AS_HELP_STRING([--without-bluetooth], [Build without gnome-bluetooth library (default: auto)]))
+AS_IF([test "x$with_bluetooth" != "xno"], [
PKG_CHECK_EXISTS([gnome-bluetooth-1.0 >= 3.1.0],
[BLUETOOTH_DIR=`$PKG_CONFIG --variable=applet_libdir gnome-bluetooth-1.0`
BLUETOOTH_LIBS=`$PKG_CONFIG --variable=applet_libs gnome-bluetooth-1.0`
@@ -123,6 +125,9 @@ PKG_CHECK_EXISTS([gnome-bluetooth-1.0 >= 3.1.0],
[AC_DEFINE([HAVE_BLUETOOTH],[0])
AC_SUBST([HAVE_BLUETOOTH],[0])
AC_MSG_RESULT([no])])
+], [AC_DEFINE([HAVE_BLUETOOTH],[0])
+ AC_SUBST([HAVE_BLUETOOTH],[0])
+ AC_MSG_RESULT([no])])
MUFFIN_GIR_DIR=`$PKG_CONFIG --variable=girdir libmuffin`
MUFFIN_TYPELIB_DIR=`$PKG_CONFIG --variable=typelibdir libmuffin`
--
1.9.2

@ -1,88 +0,0 @@
From 3dbb6dc0b3dd08e6d5ae24fa079d9443c1b66ab9 Mon Sep 17 00:00:00 2001
From: Alexandre Rostovtsev <tetromino@gentoo.org>
Date: Sat, 10 May 2014 15:14:05 -0400
Subject: [PATCH] Make networkmanager dependency optional for Gentoo
---
configure.ac | 35 ++++++++++++++++++++++++++++++++++-
js/misc/config.js.in | 2 ++
src/Makefile.am | 5 ++++-
3 files changed, 40 insertions(+), 2 deletions(-)
diff --git a/configure.ac b/configure.ac
index b5668f4..5f600dd 100644
--- a/configure.ac
+++ b/configure.ac
@@ -82,7 +82,40 @@ PKG_CHECK_MODULES(CINNAMON, gio-2.0 >= $GIO_MIN_VERSION
libstartup-notification-1.0 >= $STARTUP_NOTIFICATION_MIN_VERSION
gobject-introspection-1.0 >= $GOBJECT_INTROSPECTION_MIN_VERSION
polkit-agent-1 >= $POLKIT_MIN_VERSION xfixes
- libnm-glib libnm-util gnome-keyring-1 atk-bridge-2.0)
+ atk-bridge-2.0)
+
+##########################
+# Check for NetworkManager
+##########################
+NM_MIN_VERSION=0.9
+AC_ARG_ENABLE(networkmanager,
+ AS_HELP_STRING([--disable-networkmanager],
+ [disable NetworkManager support @<:@default=auto@:>@]),,
+ [enable_networkmanager=auto])
+
+if test "x$enable_networkmanager" != "xno"; then
+ PKG_CHECK_MODULES(NETWORKMANAGER,
+ [libnm-glib libnm-util gnome-keyring-1],
+ [have_networkmanager=yes],
+ [have_networkmanager=no])
+
+ CINNAMON_CFLAGS="$CINNAMON_CFLAGS $NETWORKMANAGER_CFLAGS"
+ CINNAMON_LIBS="$CINNAMON_LIBS $NETWORKMANAGER_LIBS"
+else
+ have_networkmanager="no (disabled)"
+fi
+
+if test "x$have_networkmanager" = "xyes"; then
+ AC_DEFINE(HAVE_NETWORKMANAGER, [1], [Define if we have NetworkManager])
+ AC_SUBST([HAVE_NETWORKMANAGER], [1])
+else
+ if test "x$enable_networkmanager" = "xyes"; then
+ AC_MSG_ERROR([Couldn't find NetworkManager.])
+ fi
+ AC_SUBST([HAVE_NETWORKMANAGER], [0])
+fi
+
+AM_CONDITIONAL(HAVE_NETWORKMANAGER, test "$have_networkmanager" = "yes")
PKG_CHECK_MODULES(CINNAMON_JS, gio-2.0 cjs-internals-1.0 >= $GJS_MIN_VERSION)
diff --git a/js/misc/config.js.in b/js/misc/config.js.in
index 704989b..df7e014 100644
--- a/js/misc/config.js.in
+++ b/js/misc/config.js.in
@@ -8,5 +8,7 @@ const PACKAGE_VERSION = '@PACKAGE_VERSION@';
const GJS_VERSION = '@GJS_VERSION@';
/* 1 if gnome-bluetooth is available, 0 otherwise */
const HAVE_BLUETOOTH = @HAVE_BLUETOOTH@;
+/* 1 if networkmanager is available, 0 otherwise */
+const HAVE_NETWORKMANAGER = @HAVE_NETWORKMANAGER@;
/* The system TLS CA list */
const CINNAMON_SYSTEM_CA_FILE = '@CINNAMON_SYSTEM_CA_FILE@';
diff --git a/src/Makefile.am b/src/Makefile.am
index 0b0a4a9..cf3a606 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -290,7 +290,10 @@ libcinnamon_la_LIBADD = \
libcinnamon_la_CPPFLAGS = $(cinnamon_cflags)
Cinnamon-0.1.gir: libcinnamon.la St-1.0.gir
-Cinnamon_0_1_gir_INCLUDES = Clutter-1.0 ClutterX11-1.0 Meta-Muffin.0 Soup-2.4 CMenu-3.0 NetworkManager-1.0 NMClient-1.0
+Cinnamon_0_1_gir_INCLUDES = Clutter-1.0 ClutterX11-1.0 Meta-Muffin.0 Soup-2.4 CMenu-3.0
+if HAVE_NETWORKMANAGER
+Cinnamon_0_1_gir_INCLUDES += NetworkManager-1.0 NMClient-1.0
+endif
Cinnamon_0_1_gir_CFLAGS = $(libcinnamon_la_CPPFLAGS) -I $(srcdir)
Cinnamon_0_1_gir_LIBS = libcinnamon.la
Cinnamon_0_1_gir_FILES = $(libcinnamon_la_gir_sources)
--
2.4.3

@ -1,26 +0,0 @@
From 19b9e5392a0b1530861d306ee962ac85c108ba1a Mon Sep 17 00:00:00 2001
From: Gilles Dartiguelongue <eva@gentoo.org>
Date: Sun, 11 Jan 2015 20:33:37 +0100
Subject: [PATCH 1/5] Use gnome backgrounds since Cinnamon isn't providing any
https://github.com/linuxmint/Cinnamon/issues/3575
---
files/usr/lib/cinnamon-settings/modules/cs_backgrounds.py | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/usr/lib/cinnamon-settings/modules/cs_backgrounds.py b/files/usr/lib/cinnamon-settings/modules/cs_backgrounds.py
index bf6dc39..83a8b04 100644
--- a/files/usr/share/cinnamon/cinnamon-settings/modules/cs_backgrounds.py
+++ b/files/usr/share/cinnamon/cinnamon-settings/modules/cs_backgrounds.py
@@ -198,7 +198,7 @@ class Module:
def get_system_backgrounds(self):
picture_list = []
folder_list = []
- properties_dir = "/usr/share/cinnamon-background-properties"
+ properties_dir = "/usr/share/gnome-background-properties"
backgrounds = []
if os.path.exists(properties_dir):
for i in os.listdir(properties_dir):
--
2.2.1

@ -1,11 +0,0 @@
--- a/files/usr/share/cinnamon/cinnamon-settings/modules/cs_themes.py
+++ b/files/usr/share/cinnamon/cinnamon-settings/modules/cs_themes.py
@@ -91,7 +91,7 @@
def _load_icon_themes(self):
dirs = ("/usr/share/icons", os.path.join(os.path.expanduser("~"), ".icons"))
- valid = walk_directories(dirs, lambda d: os.path.isdir(d) and not os.path.exists(os.path.join(d, "cursors")) and os.path.exists(os.path.join(d, "index.theme")))
+ valid = walk_directories(dirs, lambda d: os.path.isdir(d) and os.path.exists(os.path.join(d, "index.theme")))
valid.sort(lambda a,b: cmp(a.lower(), b.lower()))
res = []
for i in valid:

@ -1,56 +0,0 @@
--- a/files/usr/share/cinnamon/cinnamon-settings-users/cinnamon-settings-users.py
+++ b/files/usr/share/cinnamon/cinnamon-settings-users/cinnamon-settings-users.py
@@ -147,12 +147,11 @@
class PasswordDialog(Gtk.Dialog):
- def __init__ (self, user, password_mask, group_mask):
+ def __init__ (self, user, password_mask):
super(PasswordDialog, self).__init__()
self.user = user
self.password_mask = password_mask
- self.group_mask = group_mask
self.set_modal(True)
self.set_skip_taskbar_hint(True)
@@ -218,14 +217,7 @@
def change_password(self):
newpass = self.new_password.get_text()
self.user.set_password(newpass, "")
- mask = self.group_mask.get_text()
- if "nopasswdlogin" in mask:
- subprocess.call(["gpasswd", "-d", self.user.get_user_name(), "nopasswdlogin"])
- mask = mask.split(", ")
- mask.remove("nopasswdlogin")
- mask = ", ".join(mask)
- self.group_mask.set_text(mask)
- self.password_mask.set_text(u'\u2022\u2022\u2022\u2022\u2022\u2022')
+ self.password_mask.set_text(u'\u2022\u2022\u2022\u2022\u2022\u2022')
self.destroy()
def set_passwords_visibility(self):
@@ -563,7 +555,7 @@
model, treeiter = self.users_treeview.get_selection().get_selected()
if treeiter != None:
user = model[treeiter][INDEX_USER_OBJECT]
- dialog = PasswordDialog(user, self.password_mask, self.groups_label)
+ dialog = PasswordDialog(user, self.password_mask)
response = dialog.run()
def _on_groups_button_clicked(self, widget):
@@ -807,11 +799,11 @@
pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/cinnamon/faces/user-generic.png", 48, 48)
description = "<b>%s</b>\n%s" % (fullname, username)
piter = self.users.append(None, [new_user, pixbuf, description])
# Add the user to his/her own group and sudo if Administrator was selected
if dialog.account_type_combo.get_active() == 1:
- subprocess.call(["usermod", username, "-G", "%s,sudo,nopasswdlogin" % username])
+ subprocess.call(["usermod", username, "-G", "%s,wheel" % username])
else:
- subprocess.call(["usermod", username, "-G", "%s,nopasswdlogin" % username])
+ subprocess.call(["usermod", username, "-G", "%s" % username])
self.load_groups()
dialog.destroy()

@ -1,15 +0,0 @@
[Desktop Entry]
Type=Application
Name=Cinnamon Screensaver
Comment=Launch screensaver and locker program
Icon=preferences-desktop-screensaver
Exec=gnome-screensaver
OnlyShowIn=GNOME;
AutostartCondition=GNOME3 if-session cinnamon
NoDisplay=true
X-GNOME-Autostart-Phase=Application
X-GNOME-Autostart-Notify=true
X-GNOME-Bugzilla-Bugzilla=GNOME
X-GNOME-Bugzilla-Product=gnome-screensaver
X-GNOME-Bugzilla-Component=general
X-GNOME-Bugzilla-Version=3.6.0

@ -1,15 +0,0 @@
[Desktop Entry]
Type=Application
Name=Cinnamon2d Screensaver
Comment=Launch screensaver and locker program
Icon=preferences-desktop-screensaver
Exec=gnome-screensaver
OnlyShowIn=GNOME;
AutostartCondition=GNOME3 if-session cinnamon2d
NoDisplay=true
X-GNOME-Autostart-Phase=Application
X-GNOME-Autostart-Notify=true
X-GNOME-Bugzilla-Bugzilla=GNOME
X-GNOME-Bugzilla-Product=gnome-screensaver
X-GNOME-Bugzilla-Component=general
X-GNOME-Bugzilla-Version=3.6.0

@ -1,9 +0,0 @@
[Desktop Entry]
Name=PolicyKit Authentication Agent
Exec=/usr/libexec/polkit-gnome-authentication-agent-1
Terminal=false
Type=Application
Categories=
NoDisplay=true
OnlyShowIn=X-Cinnamon;
X-GNOME-AutoRestart=true

@ -19,6 +19,12 @@ dev-qt/qtsingleapplication qt5
media-libs/opencv qt5 -qt4
# required by mail-client/trojita-0.7 [password]
dev-libs/qtkeychain qt5
# required by media-sound/tomahawk-0.9.0_pre20161029
media-libs/liblastfm qt5
# required by media-sound/tomahawk-0.9.0_pre20161029
media-libs/libechonest qt5
# required by media-sound/tomahawk-0.9.0_pre20161029
dev-libs/quazip qt5
app-admin/packagekit-qt qt5
app-misc/qlcplus qt5

@ -10,7 +10,7 @@
~app-emulation/aqemu-0.9.2 amd64 x86
~app-emulation/lxc-1.0.8 x86
~app-emulation/lxc-2.0.5 amd64
~app-emulation/lxd-2.3 amd64 x86
~app-emulation/lxd-2.5 amd64 x86
~app-emulation/open-vm-tools-10.0.7 amd64 x86
~app-emulation/playonlinux-4.2.10 amd64 x86
~app-emulation/q4wine-1.3.3 amd64 x86
@ -163,8 +163,8 @@
~net-print/foomatic-db-engine-4.0.12 amd64 x86
~net-print/foomatic-db-ppds-4.0.20160504 amd64 x86
~net-print/gutenprint-5.2.11 amd64 x86
~net-print/hplip-3.16.9 amd64 x86
~net-print/hplip-plugin-3.16.9 amd64 x86
~net-print/hplip-3.16.10 amd64 x86
~net-print/hplip-plugin-3.16.10 amd64 x86
~net-voip/linphone-3.6.1 amd64 x86
~net-wireless/blueman-2.0.4 amd64 x86
~net-wireless/broadcom-sta-6.30.223.271 amd64 x86

@ -1,5 +1,4 @@
~app-admin/collectd-5.6.1 amd64 x86
~media-gfx/openscad-2015.03_p2 amd64 x86
~app-admin/elektra-0.8.15 amd64 x86
~app-admin/socklog-2.1.0 amd64 x86
~app-admin/syslogread-0.92 amd64 x86
@ -84,7 +83,7 @@
~dev-libs/libindicate-qt-0.2.5.91 amd64 x86
~dev-libs/libindicator-12.10.1 amd64 x86
=dev-libs/liborcus-0.9.2-r1 amd64 x86
~dev-libs/libqtxdg-1.3.0 amd64 x86
~dev-libs/libqtxdg-2.0.0 amd64 x86
~dev-libs/libtermkey-0.18 amd64 x86
~dev-libs/libvterm-0.0_pre20160305 amd64 x86
~dev-libs/mimetic-0.9.8 amd64 x86
@ -93,6 +92,7 @@
~dev-libs/nss-3.25 amd64 x86
~dev-libs/qcustomplot-1.3.2 amd64 x86
~dev-libs/qoauth-2.0.1_pre20160315 amd64 x86
~dev-libs/quazip-0.7.2 amd64 x86
~dev-libs/sni-qt-0.2.6 amd64 x86
~dev-libs/unibilium-1.1.4 amd64 x86
~dev-lua/lpeg-1.0.0 amd64 x86
@ -120,7 +120,7 @@
~dev-tex/bibtexu-3.71_p20150521 amd64 x86
~dev-util/android-sdk-update-manager-24.4.1 amd64 x86
~dev-util/bless-0.6.0 amd64 x86
~dev-util/cmake-3.5.2 amd64 x86
~dev-util/cmake-3.6.2 amd64 x86
~dev-util/codeblocks-16.01 amd64 x86
~dev-util/kbuild-0.1.9998_pre20131130 amd64 x86
~gnome-extra/cjs-2.8.0 amd64 x86
@ -132,12 +132,15 @@
~kde-misc/krusader-2.5.0 amd64 x86
~kde-misc/kscreen-1.0.71_p20150824 amd64 x86
~lxde-base/lxappearance-obconf-0.2.1 amd64 x86
~lxqt-base/libsysstat-0.3.2 amd64 x86
~media-fonts/courier-prime-1.203 amd64 x86
~media-fonts/hack-2.020 amd64 x86
~media-fonts/heuristica-0.2.1 amd64 x86
~media-fonts/infinality-ultimate-meta-1 amd64 x86
~media-fonts/signika-1.001 amd64 x86
~media-fonts/tex-gyre-2.005 amd64 x86
~media-gfx/lximage-qt-0.4.0 amd64 x86
~media-gfx/openscad-2015.03_p2 amd64 x86
~media-gfx/photoqt-1.4.1 amd64 x86
~media-libs/babl-0.1.14 amd64 x86
~media-libs/fontconfig-ultimate-2015.08.01 amd64 x86
@ -230,6 +233,7 @@
~x11-libs/qtermwidget-0.6.0 amd64 x86
~x11-misc/appmenu-qt-0.2.6 amd64 x86
~x11-misc/obconf-2.0.4 amd64 x86
~x11-misc/obconf-qt-0.9.0_p20150729 amd64 x86
~x11-misc/oroborus-desklaunch-1.1.8 amd64 x86
~x11-misc/oroborus-deskmenu-1.4.5 amd64 x86
~x11-misc/oroborus-keylaunch-1.3.9 amd64 x86

@ -1,23 +1,19 @@
~dev-libs/libqtxdg-1.2.0 amd64 x86
~lxqt-base/libsysstat-0.3.2 amd64 x86
~media-gfx/lximage-qt-0.4.0 amd64 x86
~x11-misc/obconf-qt-0.9.0_p20150729 amd64 x86
<lxqt-base/liblxqt-0.11 amd64 x86
<lxqt-base/liblxqt-mount-0.11 amd64 x86
<lxqt-base/lxqt-about-0.11 amd64 x86
<lxqt-base/lxqt-admin-0.11 amd64 x86
<lxqt-base/lxqt-common-0.11 amd64 x86
<lxqt-base/lxqt-config-0.11 amd64 x86
<lxqt-base/lxqt-globalkeys-0.11 amd64 x86
<lxqt-base/lxqt-meta-0.11 amd64 x86
<lxqt-base/lxqt-notificationd-0.11 amd64 x86
<lxqt-base/lxqt-openssh-askpass-0.11 amd64 x86
<lxqt-base/lxqt-panel-0.11 amd64 x86
<lxqt-base/lxqt-policykit-0.11 amd64 x86
<lxqt-base/lxqt-powermanagement-0.11 amd64 x86
<lxqt-base/lxqt-qtplugin-0.11 amd64 x86
<lxqt-base/lxqt-runner-0.11 amd64 x86
<lxqt-base/lxqt-session-0.11 amd64 x86
<lxqt-base/lxqt-sudo-0.11 amd64 x86
<x11-misc/pcmanfm-qt-0.11 amd64 x86
<lxqt-base/liblxqt-0.12 amd64 x86
<lxqt-base/liblxqt-mount-0.12 amd64 x86
<lxqt-base/lxqt-about-0.12 amd64 x86
<lxqt-base/lxqt-admin-0.12 amd64 x86
<lxqt-base/lxqt-common-0.12 amd64 x86
<lxqt-base/lxqt-config-0.12 amd64 x86
<lxqt-base/lxqt-globalkeys-0.12 amd64 x86
<lxqt-base/lxqt-meta-0.12 amd64 x86
<lxqt-base/lxqt-notificationd-0.12 amd64 x86
<lxqt-base/lxqt-openssh-askpass-0.12 amd64 x86
<lxqt-base/lxqt-panel-0.12 amd64 x86
<lxqt-base/lxqt-policykit-0.12 amd64 x86
<lxqt-base/lxqt-powermanagement-0.12 amd64 x86
<lxqt-base/lxqt-qtplugin-0.12 amd64 x86
<lxqt-base/lxqt-runner-0.12 amd64 x86
<lxqt-base/lxqt-session-0.12 amd64 x86
<lxqt-base/lxqt-sudo-0.12 amd64 x86
<x11-libs/libfm-qt-0.12 amd64 x86
<x11-misc/pcmanfm-qt-0.12 amd64 x86

@ -18,6 +18,7 @@ app-office/orage
app-office/scribus
app-office/texmacs
app-office/texmaker
app-office/texstudio
app-text/calibre
app-text/cherrytree
app-text/fbless

@ -18,6 +18,7 @@ app-office/orage
app-office/scribus
app-office/texmacs
app-office/texmaker
@@ -807,11 +799,11 @@
description = "<b>%s</b>\n%s" % (fullname, username)
piter = self.users.append(None, [new_user, pixbuf, description])
- # Add the user to his/her own group and sudo if Administrator was selected
+ # Add the user to his/her own group and wheel if Administrator was selected
if dialog.account_type_combo.get_active() == 1:
app-office/texstudio
app-text/calibre
app-text/cherrytree
app-text/fbless

Loading…
Cancel
Save